aboutsummaryrefslogtreecommitdiff
path: root/build/mainline_modules_sdks.py
diff options
context:
space:
mode:
Diffstat (limited to 'build/mainline_modules_sdks.py')
-rwxr-xr-xbuild/mainline_modules_sdks.py13
1 files changed, 10 insertions, 3 deletions
diff --git a/build/mainline_modules_sdks.py b/build/mainline_modules_sdks.py
index aef518f1..4de99ec4 100755
--- a/build/mainline_modules_sdks.py
+++ b/build/mainline_modules_sdks.py
@@ -728,7 +728,7 @@ R = BuildRelease(
)
S = BuildRelease(
name="S",
# Generate a snapshot for S using Soong.
creator=create_sdk_snapshots_in_soong,
# This requires the SoongConfigBoilerplateInserter transformation to be
# applied.
@@ -736,9 +736,16 @@ S = BuildRelease(
)
Tiramisu = BuildRelease(
name="Tiramisu",
# Generate a snapshot for Tiramisu using Soong.
creator=create_sdk_snapshots_in_soong,
- # This supports the use_source_config_var property.
+ # This build release supports the use_source_config_var property.
+ preferHandling=PreferHandling.USE_SOURCE_CONFIG_VAR_PROPERTY,
+)
+UpsideDownCake = BuildRelease(
+ name="UpsideDownCake",
+ # Generate a snapshot for this build release using Soong.
+ creator=create_sdk_snapshots_in_soong,
+ # This build release supports the use_source_config_var property.
preferHandling=PreferHandling.USE_SOURCE_CONFIG_VAR_PROPERTY,
)
@@ -728,7 +728,7 @@ R = BuildRelease(
S = BuildRelease(
name="S",
- # Generate a snapshot for S using Soong.
+ # Generate a snapshot for this build release using Soong.
creator=create_sdk_snapshots_in_soong,
# This requires the SoongConfigBoilerplateInserter transformation to be
@@ -736,9 +736,16 @@ S = BuildRelease(
Tiramisu = BuildRelease(
name="Tiramisu",
- # Generate a snapshot for Tiramisu using Soong.
+ # Generate a snapshot for this build release using Soong.
creator=create_sdk_snapshots_in_soong,